@@ -2,4 +2,4 @@ from .referrals import *
 from .actions import *
 from .partners import *
 from .support import *
-from .payments import *
+from .accounting import *
